Column

Struct Column 

pub struct Column { /* private fields */ }
A type-erased contiguous container for data of a homogeneous type.

Conceptually, a Column is very similar to a type-erased Box<[T]>. It also stores the change detection ticks for its components, kept in two separate contiguous buffers internally. An element shares its data across these buffers by using the same index (i.e. the entity at row 3 has it’s data at index 3 and its change detection ticks at index 3).

Like many other low-level storage types, Column has a limited and highly unsafe interface. It’s highly advised to use higher level types and their safe abstractions instead of working directly with Column.

For performance reasons, Column does not does not store it’s capacity and length. This type is used by Table and ComponentSparseSet, where the corresponding capacity and length can be found.

Implementations



impl Column

pub fn with_capacity(component_info: &ComponentInfo, capacity: usize) -> Column

Create a new Column with the given capacity.

pub unsafe fn get_data_slice<T>(&self, len: usize) -> &[UnsafeCell<T>]

Get a slice to the data stored in this Column.

Safety
  • T must match the type of data that’s stored in this Column
  • len must match the actual length of this column (number of elements stored)

pub unsafe fn get_added_ticks_slice(&self, len: usize) -> &[UnsafeCell<Tick>]

Get a slice to the added ticks in this Column.

Safety
  • len must match the actual length of this column (number of elements stored)

pub unsafe fn get_changed_ticks_slice(&self, len: usize) -> &[UnsafeCell<Tick>]

Get a slice to the changed ticks in this Column.

Safety
  • len must match the actual length of this column (number of elements stored)

pub unsafe fn get_changed_by_slice( &self, len: usize, ) -> MaybeLocation<&[UnsafeCell<&'static Location<'static>>]>

Get a slice to the calling locations that last changed each value in this Column

Safety
  • len must match the actual length of this column (number of elements stored)

pub unsafe fn get_data_unchecked(&self, row: TableRow) -> Ptr<'_>

Fetches a read-only reference to the data at row. This does not do any bounds checking.

Safety
  • row must be within the range [0, self.len()).
  • no other mutable reference to the data of the same row can exist at the same time

pub unsafe fn get_changed_by_unchecked( &self, row: TableRow, ) -> MaybeLocation<&UnsafeCell<&'static Location<'static>>>

Fetches the calling location that last changed the value at row.

This function does not do any bounds checking.

Safety

row must be within the range [0, self.len()).

pub unsafe fn get_added_tick_unchecked( &self, row: TableRow, ) -> &UnsafeCell<Tick>

Fetches the “added” change detection tick for the value at row. This function does not do any bounds checking.

Safety

row must be within the range [0, self.len()).

pub unsafe fn get_changed_tick_unchecked( &self, row: TableRow, ) -> &UnsafeCell<Tick>

Fetches the “changed” change detection tick for the value at row This function does not do any bounds checking.

Safety

row must be within the range [0, self.len()).

pub unsafe fn get_ticks_unchecked(&self, row: TableRow) -> ComponentTicks

Fetches the change detection ticks for the value at row. This function does not do any bounds checking.

Safety

row must be within the range [0, self.len()).

pub fn get_drop(&self) -> Option<unsafe fn(OwningPtr<'_>)>

Returns the drop function for elements of the column, or None if they don’t need to be dropped.